pub fn refget_router(state: RefgetState) -> RouterExpand description
Create the combined refget router with both sequences and sequence collections endpoints.
pub fn refget_router(state: RefgetState) -> RouterCreate the combined refget router with both sequences and sequence collections endpoints.